/*
   Made by Imara Speek and Aadjan van der Helm, edited for Simon game by Paul Groenendaal
   For the Simon Says game

   Version 2

   Updated by Ian Paschal, 2016

*/

/*  0 = RED
 *  1 = BLUE
 *  2 = GREEN
 *  4 = YELLOW
 */

// Set up libraries:
#include <ChainableLED.h>
#define NUM_LEDS 4

// Defining the generic analog sensors
int sensor0 = A0;    // generic sensor 0
int sensor1 = A1;    // generic sensor 1
int sensor2 = A2;    // generic sensor 2
int sensor3 = A3;    // generic sensor 3

// values for the sensors
int sensorValue0 = 0;
int sensorValue1 = 0;
int sensorValue2 = 0;
int sensorValue3 = 0;

// Create the LEDs (pin out, pin return, LEDs along the way):
ChainableLED leds(7, 8, NUM_LEDS);

// receiving values from the max patch
int red = 0;
int blue = 0;
int green = 0;
int yellow = 0;

unsigned long lastTimeSent = 0;

void setup() {
  // Initiate serial communication
  Serial.begin(38400);

  // Start up the LEDs:
  leds.init();

  // startup show
  leds.setColorRGB(0, 255, 0, 0);
  delay(500);
  leds.setColorRGB(1, 255, 255, 0);
  delay(500);
  leds.setColorRGB(2, 0, 255, 0);
  delay(500);
  leds.setColorRGB(3, 0, 0, 255);
  delay(500);
  
  // Turn all LEDs off:
  leds.setColorRGB(0, 0, 0, 0);
  leds.setColorRGB(1, 0, 0, 0);
  leds.setColorRGB(2, 0, 0, 0);
  leds.setColorRGB(3, 0, 0, 0);

  pinMode(sensor0, INPUT);
  pinMode(sensor1, INPUT);
  pinMode(sensor2, INPUT);
  pinMode(sensor3, INPUT);
}

void loop() {
  // read the serial input from the max patch
  // only one type of input expected
  
  while (Serial.available()) {

    // parse the valid integers into the RGB led
    red    = Serial.parseInt() * 255;
    blue   = Serial.parseInt() * 255;
    green  = Serial.parseInt() * 255;
    yellow = Serial.parseInt() * 255;

    // look for a newline
    if (Serial.read() == '\n') {
      
      // Write to the ledstrip
      if (red != 0) {
        leds.setColorRGB(0, 255, 0, 0);
      } else {
        leds.setColorRGB(0, 0, 0, 0);
      }
      if (yellow != 0) {
        leds.setColorRGB(1, 255, 255, 0);
      } else {
        leds.setColorRGB(1, 0, 0, 0);
      }
      if (green != 0) {
        leds.setColorRGB(2, 0, 255, 0);
      } else {
        leds.setColorRGB(2, 0, 0, 0);
      }
      if (blue != 0) {
        leds.setColorRGB(3, 0, 0, 255);
      } else {
        leds.setColorRGB(3, 0, 0, 0);
      }
    }
  }
  

  // Let's send max 25 times per second
  if (millis() > (lastTimeSent + 40))
  {
    // read the value from the sensors:
    sensorValue0 = analogRead(sensor0);
    sensorValue1 = analogRead(sensor1);
    sensorValue2 = analogRead(sensor2);
    sensorValue3 = analogRead(sensor3);

    // print to the maxpatch
    Serial.print(sensorValue0);
    Serial.print(" ");
    Serial.print(sensorValue1);
    Serial.print(" ");
    Serial.print(sensorValue2);
    Serial.print(" ");
    Serial.print(sensorValue3);
    Serial.print("\n");
    lastTimeSent = millis();
  }

}
